from flask import Flask
import toml

from db import db
from forms import forms
from game_api import game


def init_app():
    app = Flask(__name__)

    with open("secrets.toml") as infile:
        secrets = toml.load(infile)
    app.secret_key = secrets["secret_key"]
    app.config["SQLALCHEMY_DATABASE_URI"] = secrets["db_uri"]
    app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False

    app.register_blueprint(forms)
    app.register_blueprint(game, url_prefix="/game")

    db.init_app(app)
    db.create_all(app=app)

    return app


if __name__ == "__main__":
    init_app().run("0.0.0.0", 5000)
